
# Slot: classes


class definitions

URI: [linkml:classes](https://w3id.org/linkml/classes)


## Domain and Range

[SchemaDefinition](SchemaDefinition.md) &#8594;  <sub>0..\*</sub> [ClassDefinition](ClassDefinition.md)

## Parents


## Children


## Used by

 * [SchemaDefinition](SchemaDefinition.md)
